@@ -9,10 +9,19 @@ __all__ = ()
 
 # Raise the given exception class from the caught exception, preserving
 # stack trace and message as much as possible.
-def raise_from(klass, from_value):
+def raise_from(klass, from_value, extra_message = None):
   try:
     if from_value is None:
+      if extra_message is not None:
+        raise klass(extra_message)
       raise klass()
-    raise klass(*from_value.args) from from_value
+
+    args = list(from_value.args)
+    if extra_message is not None:
+      if len(args) and isinstance(args[0], str):
+        args[0] += ' -- ' + extra_message
+      else:
+        args.append(extra_message)
+    raise klass(*args) from from_value
   finally:
     klass = None
